@@ -101,7 +101,7 @@ class ActionConfigurationAction(workflows.Action):
         help_text=_("Id of nova instance for backup"),
         required=False)
 
-    nova_network_id = forms.CharField(
+    nova_restore_network = forms.CharField(
         label=_("Nova network ID *"),
         help_text=_("Id of nova network for recover"),
         required=False)
@@ -157,10 +157,18 @@ class ActionConfigurationAction(workflows.Action):
         cleaned_data = super(ActionConfigurationAction, self).clean()
 
         if cleaned_data.get('action') == 'backup':
-            if cleaned_data.get('mode') == 'cinder' \
-                    or cleaned_data.get('mode') == 'nova':
-                self._check_container(cleaned_data)
+            if cleaned_data.get('mode') == 'cinder':
+                if cleaned_data.get('storage') != 'swift':
+                    self._check_container(cleaned_data)
                 self._check_backup_name(cleaned_data)
+                self._check_cinder_vol_id(cleaned_data)
+                return cleaned_data
+
+            if cleaned_data.get('mode') == 'nova':
+                if cleaned_data.get('storage') != 'swift':
+                    self._check_container(cleaned_data)
+                self._check_backup_name(cleaned_data)
+                self._check_nova_inst_id(cleaned_data)
                 return cleaned_data
 
             self._check_backup_name(cleaned_data)
@@ -176,20 +184,25 @@ class ActionConfigurationAction(workflows.Action):
             self._check_container(cleaned_data)
             self._check_backup_name(cleaned_data)
             self._check_nova_inst_id(cleaned_data)
-            self._check_nova_network_id(cleaned_data)
+            self._check_nova_restore_network(cleaned_data)
 
         return cleaned_data
 
-    def _check_nova_network_id(self, cleaned_data):
-        if not cleaned_data.get('nova_network_id'):
+    def _check_nova_restore_network(self, cleaned_data):
+        if not cleaned_data.get('nova_restore_network'):
             msg = _("You must define nova network id to restore.")
-            self._errors['nova_inst_id'] = self.error_class([msg])
+            self._errors['nova_restore_network'] = self.error_class([msg])
 
     def _check_nova_inst_id(self, cleaned_data):
         if not cleaned_data.get('nova_inst_id'):
-            msg = _("You must define nova instance id to restore.")
+            msg = _("You must define nova instance id to restore or backup.")
             self._errors['nova_inst_id'] = self.error_class([msg])
 
+    def _check_cinder_vol_id(self, cleaned_data):
+        if not cleaned_data.get('cinder_vol_id'):
+            msg = _("You must define cinder volume id to backup.")
+            self._errors['cinder_vol_id'] = self.error_class([msg])
+
     def _check_restore_abs_path(self, cleaned_data):
         if not cleaned_data.get('restore_abs_path'):
             msg = _("You must define a path to restore.")
@@ -262,7 +275,7 @@ class ActionConfiguration(workflows.Step):
                    'restore_from_date',
                    'cinder_vol_id',
                    'nova_inst_id',
-                   'nova_network_id',
+                   'nova_restore_network',
                    'get_object',
                    'dst_file',
                    'remove_older_than',
@@ -318,7 +331,7 @@ class AdvancedConfigurationAction(workflows.Action):
         widget=forms.URLInput(),
         required=False)
 
-    os_auth_ver = forms.ChoiceField(
+    os_identity_api_version = forms.ChoiceField(
         label=_("OpenStack Authentication Version"),
         help_text=_("Swift auth version, could be 1, 2 or 3"),
         required=False)
@@ -459,7 +472,7 @@ class AdvancedConfigurationAction(workflows.Action):
         widget=forms.CheckboxInput(),
         required=False)
 
-    def populate_os_auth_ver_choices(self, request, context):
+    def populate_os_identity_api_version_choices(self, request, context):
         return [
             ('2', _("v2")),
             ('1', _("v1")),
@@ -477,7 +490,7 @@ class AdvancedConfiguration(workflows.Step):
     contributes = ('exclude',
                    'log_file',
                    'proxy',
-                   'os_auth_ver',
+                   'os_identity_api_version',
                    'upload_limit',
                    'download_limit',
                    'compression',
