@@ -41,11 +41,12 @@ def client(request):
         'auth_url': getattr(settings, 'OPENSTACK_KEYSTONE_URL'),
         'endpoint': api_url,
         'version': ks_version,
-        'cert': cacert
+        'cacert': cacert
     }
 
     if ks_version == 3:
         credentials['project_name'] = request.user.project_name
+        credentials['project_id'] = request.user.project_id
         credentials['project_domain_name'] = \
             request.user.domain_name or 'Default'
 
@@ -441,7 +442,7 @@ class Client(object):
         return [utils.ClientObject(
             c.get('client', {}).get('hostname'),
             c.get('client', {}).get('client_id'),
-            c.get('uuid')
+            c.get('client', {}).get('uuid')
         ) for c in clients]
 
     def get(self, client_id, json=False):
