@@ -13,7 +13,6 @@
 # limitations under the License.
 
 import datetime
-import logging
 
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
@@ -26,14 +25,10 @@ from horizon import workflows
 import disaster_recovery.api.api as freezer_api
 
 
-LOG = logging.getLogger(__name__)
-
-
 class SessionConfigurationAction(workflows.Action):
     description = forms.CharField(
         label=_("Session Name"),
-        help_text=_("Define a name for this session"),
-        required=True)
+        help_text=_("Define a name for this session"))
 
     session_id = forms.CharField(
         widget=forms.HiddenInput(),
